================
Database service
================

The Database service (Trove) provides scalable and reliable Cloud Database as a
Service provisioning functionality for both relational and non-relational
database engines.

.. toctree::

   get_started.rst
   apache-mod-wsgi.rst
   install-devstack.rst
   install-manual.rst
   install-ubuntu.rst
   install-redhat.rst
   install-suse.rst
   dashboard.rst
   verify.rst
   next-steps.rst
